pub(crate) struct HitTest<'a> {
point_to_test: LayoutPoint,
projected_point_to_test: Option<(ScrollTreeNodeId, LayoutPoint, FastLayoutTransform)>,
stacking_context_tree: &'a StackingContextTree,
results: Vec<ElementsFromPointResult>,
clip_hit_test_results: FxHashMap<ClipId, bool>,
collected_reference_frame_clips: Vec<ClipId>,
}Fields
point_to_test: LayoutPointThe point to test for this hit test, relative to the page.
projected_point_to_test: Option<(ScrollTreeNodeId, LayoutPoint, FastLayoutTransform)>A cached version of Self::point_to_test projected to a spatial node, to avoid
doing a lot of matrix math over and over.
stacking_context_tree: &'a StackingContextTreeThe stacking context tree against which to perform the hit test.
results: Vec<ElementsFromPointResult>The resulting [HitTestResultItems] for this hit test.
clip_hit_test_results: FxHashMap<ClipId, bool>A cache of hit test results for shared clip nodes.
collected_reference_frame_clips: Vec<ClipId>Collected reference frame clips. For painting, reference frame clips are handled by enclosing reference frames in stacking contexts, but we don’t have that option here, so we must handle them manually.
Implementations
Sourceimpl<'a> HitTest<'a>
impl<'a> HitTest<'a>
pub(crate) fn run( stacking_context_tree: &'a StackingContextTree, point_to_test: LayoutPoint, ) -> Vec<ElementsFromPointResult>
Sourcefn hit_test_clip_id(&mut self, clip_id: ClipId) -> bool
fn hit_test_clip_id(&mut self, clip_id: ClipId) -> bool
Perform a hit test against the clip node for the given ClipId, returning
true if it is not clipped out or false if is clipped out.
fn hit_test_individual_clip_id(&mut self, clip_id: ClipId) -> bool
Sourcefn location_in_spatial_node(
&mut self,
scroll_tree_node_id: ScrollTreeNodeId,
) -> Option<(LayoutPoint, FastLayoutTransform)>
fn location_in_spatial_node( &mut self, scroll_tree_node_id: ScrollTreeNodeId, ) -> Option<(LayoutPoint, FastLayoutTransform)>
Get the hit test location in the coordinate system of the given spatial node,
returning None if the transformation is uninvertible or the point cannot be
projected into the spatial node.